unless defined?(Motion::Project::Config)
  fail('This file must be required within a RubyMotion project Rakefile.')
end

module Motion::Project
  class Config
    variable :x_files

    def x_files(&block)
      @x_files ||= Motion::Project::XFiles.new(self)
    end
  end

  class XFiles
    TEMPLATES = [:ios, :android, :osx]

    def initialize(config)
      @config = config
      @excluded_templates = (TEMPLATES - [@config.template]).map(&:to_s)
    end

    def filter!
      @config.files.each do |file|
        if exclude?(file)
          @config.files.delete(file)
        end
      end
    end

    private

    def exclude?(file)
      @excluded_templates.any? do |template|
        file_matches_template?(file, template)
      end
    end

    def file_matches_template?(file, template)
      file.match(/\/#{template}\//) || file.match(/#{template}.rb$/)
    end
  end
end
